==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/OnCollapsedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { OnCollapsedEventArgsDescription } from "./OnCollapsedEventArgsDescription";
/**
 * @hidden
 */
export let OnCollapsedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class OnCollapsedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (OnCollapsedEventArgsDescriptionMetadata.a == null) {
                OnCollapsedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                OnCollapsedEventArgsDescriptionMetadata.c(OnCollapsedEventArgsDescriptionMetadata.a);
            }
            if (a.j(OnCollapsedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(OnCollapsedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            OnCollapsedEventArgsDescriptionMetadata.b(a);
            a.aa("OnCollapsedEventArgs", () => new OnCollapsedEventArgsDescription());
            a.z("OnCollapsedEventArgs", OnCollapsedEventArgsDescriptionMetadata.a);
        }
    }
    OnCollapsedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(OnCollapsedEventArgsDescriptionMetadata, 'OnCollapsedEventArgsDescriptionMetadata');
    OnCollapsedEventArgsDescriptionMetadata.a = null;
    return OnCollapsedEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/OnCollapsedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { OnCollapsedEventArgsDescription } from "./OnCollapsedEventArgsDescription";
/**
 * @hidden
 */
export let OnCollapsedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class OnCollapsedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (OnCollapsedEventArgsDescriptionMetadata.a == null) {
                OnCollapsedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                OnCollapsedEventArgsDescriptionMetadata.c(OnCollapsedEventArgsDescriptionMetadata.a);
            }
            if (a.k(OnCollapsedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(OnCollapsedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            OnCollapsedEventArgsDescriptionMetadata.b(a);
            a.ac("OnCollapsedEventArgs", () => new OnCollapsedEventArgsDescription());
            a.ab("OnCollapsedEventArgs", OnCollapsedEventArgsDescriptionMetadata.a);
        }
    }
    OnCollapsedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(OnCollapsedEventArgsDescriptionMetadata, 'OnCollapsedEventArgsDescriptionMetadata');
    OnCollapsedEventArgsDescriptionMetadata.a = null;
    return OnCollapsedEventArgsDescriptionMetadata;
})();
